========
Coil CMS
========

Making Nikola accessible for non-programmers, casual users, and all other
people that don’t feel comfortable using the command line.

Setup
-----

Setting up Coil CMS is described in `the documentation <https://coil.readthedocs.org/en/latest/admin/setup/>`_.
